config/all library

Classes

AutolinkNoLeadingSpaceSyntax
An inline syntax that matches URLs NOT preceded by whitespace or other valid delimiters.
BlockConfig
ContainerConfig
InlineConfig
LeafConfig
MarkdownConfig
use MarkdownConfig to set various configurations for MarkdownWidget
MarkdownGenerator
use MarkdownGenerator to transform markdown data to Widget list, so you can render it by any type of ListView
TocController
TocController manages the state and coordination between TocWidget and MarkdownWidget.
TocItem
Represents a single item in the Table of Contents.
TocItemBuilderData
Data passed to TocItemBuilder for building custom TOC items.
TocWidget
A widget that displays a Table of Contents for markdown content.
WidgetConfig

Enums

MarkdownTag
the tags of markdown, see https://spec.commonmark.org/0.30/

Extensions

ColorExtension on Color

Properties

headingTag2Level Map<String, int>
Maps heading tag names to their hierarchy level.
final

Typedefs

HeadingNodeFilter = bool Function(HeadingNode toc)
RichTextBuilder = Widget Function(InlineSpan span)
SpanNodeBuilder = TextSpan Function(SpanNode spanNode)
TocIndexCallback = void Function(int index)
Callback type for index change events
TocItemBuilder = Widget? Function(TocItemBuilderData data)
Builder function for creating custom TOC item widgets.
TocListCallback = void Function(List<TocItem> list)
Callback type for TOC list change events
ValueCallback<T> = void Function(T value)