config/toc library

Classes

TocController
TocController manages the state and coordination between TocWidget and MarkdownWidget.
TocItem
Represents a single item in the Table of Contents.
TocItemBuilderData
Data passed to TocItemBuilder for building custom TOC items.
TocWidget
A widget that displays a Table of Contents for markdown content.

Properties

headingTag2Level Map<String, int>
Maps heading tag names to their hierarchy level.
final

Typedefs

TocIndexCallback = void Function(int index)
Callback type for index change events
TocItemBuilder = Widget? Function(TocItemBuilderData data)
Builder function for creating custom TOC item widgets.
TocListCallback = void Function(List<TocItem> list)
Callback type for TOC list change events