TocItem class

Represents a single item in the Table of Contents.

Each TocItem corresponds to a heading in the markdown document and contains information needed for TOC display and navigation.

Constructors

TocItem({required HeadingNode node, required int widgetIndex, required int tocListIndex})

Properties

hashCode int
The hash code for this object.
no setterinherited
node HeadingNode
The heading node containing the heading text, level, and styling
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tocListIndex int
The index of this item in the TOC list.
final
widgetIndex int
The index of this heading in the MarkdownGenerator's widget tree.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited