widgetIndex property
The index of this heading in the MarkdownGenerator's widget tree.
This index is used to scroll to the correct position when the TOC item is tapped.
Implementation
final int widgetIndex;
The index of this heading in the MarkdownGenerator's widget tree.
This index is used to scroll to the correct position when the TOC item is tapped.
final int widgetIndex;