TocItemBuilderData class

Data passed to TocItemBuilder for building custom TOC items.

Constructors

TocItemBuilderData({required int index, required TocItem toc, required int currentIndex, required ValueChanged<int> refreshIndexCallback, required AutoScrollController autoScrollController})

Properties

autoScrollController → AutoScrollController
The AutoScrollController used for scrolling the TOC list.
final
currentIndex int
The currently selected TOC list index
final
hashCode int
The hash code for this object.
no setterinherited
index int
The index of this item in the TOC list
final
refreshIndexCallback ValueChanged<int>
Callback to change the current index.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toc TocItem
The TOC item data
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited