TocWidget class

A widget that displays a Table of Contents for markdown content.

The TocWidget shows a list of all headings in the markdown document. It automatically highlights the currently visible heading and supports tap-to-scroll functionality.

Inheritance

Constructors

TocWidget({Key? key, required TocController controller, ScrollPhysics? physics, bool shrinkWrap = false, EdgeInsetsGeometry? padding, TocItemBuilder? itemBuilder, TextStyle? tocTextStyle, TextStyle? currentTocTextStyle})
const

Properties

controller TocController
The controller that manages TOC state and coordination.
final
currentTocTextStyle TextStyle
Text style for the currently active TOC item.
final
hashCode int
The hash code for this object.
no setterinherited
itemBuilder TocItemBuilder?
Custom builder for TOC items.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsetsGeometry?
Padding for the list view.
final
physics ScrollPhysics?
The scroll physics for the TOC list view.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shrinkWrap bool
Whether the list view should shrink-wrap its content.
final
tocTextStyle TextStyle
Text style for non-current TOC items.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TocWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited