controller property
The controller that manages TOC state and coordination.
This must not be null and should be shared with the corresponding MarkdownWidget.
Implementation
final TocController controller;
The controller that manages TOC state and coordination.
This must not be null and should be shared with the corresponding MarkdownWidget.
final TocController controller;