TableConfig class

Implemented types

Constructors

TableConfig({Map<int, TableColumnWidth>? columnWidths, TableColumnWidth? defaultColumnWidth, TextDirection? textDirection, TableBorder? border, TableCellVerticalAlignment? defaultVerticalAlignment, TextBaseline? textBaseline, Decoration? headerRowDecoration, Decoration? bodyRowDecoration, TextStyle? headerStyle, TextStyle? bodyStyle, WidgetWrapper? wrapper, EdgeInsets headPadding = const EdgeInsets.fromLTRB(8, 4, 8, 4), EdgeInsets bodyPadding = const EdgeInsets.fromLTRB(8, 4, 8, 4), RichTextBuilder? richTextBuilder})
const

Properties

bodyPadding EdgeInsets
final
bodyRowDecoration Decoration?
final
bodyStyle TextStyle?
final
border TableBorder?
final
columnWidths Map<int, TableColumnWidth>?
final
defaultColumnWidth TableColumnWidth?
final
defaultVerticalAlignment TableCellVerticalAlignment?
final
hashCode int
The hash code for this object.
no setterinherited
headerRowDecoration Decoration?
final
headerStyle TextStyle?
final
headPadding EdgeInsets
final
richTextBuilder RichTextBuilder?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
every config has a tag
no setteroverride
textBaseline TextBaseline?
final
textDirection TextDirection?
final
wrapper WidgetWrapper?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited