dispose method
void
dispose()
Releases all resources and listeners associated with this controller.
After calling dispose, the controller should not be used.
Implementation
void dispose() {
if (_isDisposed) return;
_isDisposed = true;
_widgetIndex2TocItem.clear();
_indexChangeListeners.clear();
_listChangeListeners.clear();
_jumpToWidgetIndexCallback = null;
}