wrapCode property
Whether to wrap the code when it exceeds the width of the code block. If false (default), the code will be horizontally scrollable. If true, the code will wrap to fit the width.
Implementation
final bool wrapCode;
Whether to wrap the code when it exceeds the width of the code block. If false (default), the code will be horizontally scrollable. If true, the code will wrap to fit the width.
final bool wrapCode;